@@ -138,7 +138,7 @@ private:
 class GanttHeaderView : public QHeaderView
 {
 public:
-    explicit GanttHeaderView(QWidget *parent = Q_NULLPTR) : QHeaderView(Qt::Horizontal, parent)
+    explicit GanttHeaderView(QWidget *parent = nullptr) : QHeaderView(Qt::Horizontal, parent)
     {
     }
 
@@ -353,7 +353,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mLeftView->clear();
     uint index = 0;
     // item for every calendar
-    TimelineItem *item = Q_NULLPTR;
+    TimelineItem *item = nullptr;
     Akonadi::ETMCalendar::Ptr calres = calendar();
     if (!calres) {
         item = new TimelineItem(calendar(),
@@ -367,7 +367,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
         const CalendarSupport::CollectionSelection *colSel = collectionSelection();
         const Akonadi::Collection::List collections = colSel->selectedCollections();
 
-        Q_FOREACH (const Akonadi::Collection &collection, collections) {
+        for (const Akonadi::Collection &collection : collections) {
             if (collection.contentMimeTypes().contains(Event::eventMimeType())) {
                 item = new TimelineItem(calendar(),
                                         index++,
@@ -396,7 +396,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
      * updateScene() call otherwise.
      */
     QAbstractItemModel *ganttModel = d->mGantt->model();
-    d->mGantt->setModel(Q_NULLPTR);
+    d->mGantt->setModel(nullptr);
 
     KCalCore::Event::List events;
     KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
