@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@ class CreateColorGui_test : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CreateColorGui_test(QWidget *parent = Q_NULLPTR);
+    explicit CreateColorGui_test(QWidget *parent = nullptr);
     ~CreateColorGui_test();
 private:
     void createListWidgetItem();
